Class: Google::Cloud::PubSub::V1::AIInference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/pubsub/v1/pubsub.rb

Overview

Configuration for making inference requests against Vertex AI models.

Defined Under Namespace

Classes: UnstructuredInference

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint::String

Returns Required. An endpoint to a Vertex AI model of the form projects/{project}/locations/{location}/endpoints/{endpoint} or projects/{project}/locations/{location}/publishers/{publisher}/models/{model}. Vertex AI API requests will be sent to this endpoint.

Returns:

  • (::String)

    Required. An endpoint to a Vertex AI model of the form projects/{project}/locations/{location}/endpoints/{endpoint} or projects/{project}/locations/{location}/publishers/{publisher}/models/{model}. Vertex AI API requests will be sent to this endpoint.



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 774

class AIInference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for making inferences using arbitrary JSON payloads.
  # @!attribute [rw] parameters
  #   @return [::Google::Protobuf::Struct]
  #     Optional. A parameters object to be included in each inference request.
  #     The parameters object is combined with the data field of the Pub/Sub
  #     message to form the inference request.
  class UnstructuredInference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#service_account_email::String

Returns Optional. The service account to use to make prediction requests against endpoints. The resource creator or updater that specifies this field must have iam.serviceAccounts.actAs permission on the service account. If not specified, the Pub/Sub service agent, service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com, is used.

Returns:

  • (::String)

    Optional. The service account to use to make prediction requests against endpoints. The resource creator or updater that specifies this field must have iam.serviceAccounts.actAs permission on the service account. If not specified, the Pub/Sub service agent, service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com, is used.



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 774

class AIInference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for making inferences using arbitrary JSON payloads.
  # @!attribute [rw] parameters
  #   @return [::Google::Protobuf::Struct]
  #     Optional. A parameters object to be included in each inference request.
  #     The parameters object is combined with the data field of the Pub/Sub
  #     message to form the inference request.
  class UnstructuredInference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unstructured_inference::Google::Cloud::PubSub::V1::AIInference::UnstructuredInference

Returns Optional. Requests and responses can be any arbitrary JSON object.

Returns:



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 774

class AIInference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for making inferences using arbitrary JSON payloads.
  # @!attribute [rw] parameters
  #   @return [::Google::Protobuf::Struct]
  #     Optional. A parameters object to be included in each inference request.
  #     The parameters object is combined with the data field of the Pub/Sub
  #     message to form the inference request.
  class UnstructuredInference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end