Class: Google::Cloud::PubSub::V1::AIInference::UnstructuredInference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/pubsub/v1/pubsub.rb

Overview

Configuration for making inferences using arbitrary JSON payloads.

Instance Attribute Summary collapse

Instance Attribute Details

#parameters::Google::Protobuf::Struct

Returns Optional. A parameters object to be included in each inference request. The parameters object is combined with the data field of the Pub/Sub message to form the inference request.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. A parameters object to be included in each inference request. The parameters object is combined with the data field of the Pub/Sub message to form the inference request.



784
785
786
787
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 784

class UnstructuredInference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end