Class: Google::Cloud::PubSub::V1::IngestionFailureEvent::AwsKinesisFailureReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/pubsub/v1/pubsub.rb

Overview

Failure when ingesting from an AWS Kinesis source.

Instance Attribute Summary collapse

Instance Attribute Details

#api_violation_reason::Google::Cloud::PubSub::V1::IngestionFailureEvent::ApiViolationReason

Returns Optional. The message failed to be published due to an API violation. This is only set when the size of the data field of the Kinesis record is zero.

Note: The following fields are mutually exclusive: api_violation_reason, schema_violation_reason, message_transformation_failure_reason. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::PubSub::V1::IngestionFailureEvent::ApiViolationReason)

    Optional. The message failed to be published due to an API violation. This is only set when the size of the data field of the Kinesis record is zero.

    Note: The following fields are mutually exclusive: api_violation_reason, schema_violation_reason, message_transformation_failure_reason. If a field in that set is populated, all other fields in the set will automatically be cleared.



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#message_transformation_failure_reason::Google::Cloud::PubSub::V1::IngestionFailureEvent::MessageTransformationFailureReason

Returns Optional. Failure encountered when applying a message transformation to the Pub/Sub message.

Note: The following fields are mutually exclusive: message_transformation_failure_reason, schema_violation_reason, api_violation_reason. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partition_key::String

Returns Optional. The partition key of the message that failed to be ingested.

Returns:

  • (::String)

    Optional. The partition key of the message that failed to be ingested.



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema_violation_reason::Google::Cloud::PubSub::V1::IngestionFailureEvent::SchemaViolationReason

Returns Optional. The Pub/Sub message failed schema validation.

Note: The following fields are mutually exclusive: schema_violation_reason, message_transformation_failure_reason, api_violation_reason. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::PubSub::V1::IngestionFailureEvent::SchemaViolationReason)

    Optional. The Pub/Sub message failed schema validation.

    Note: The following fields are mutually exclusive: schema_violation_reason, message_transformation_failure_reason, api_violation_reason. If a field in that set is populated, all other fields in the set will automatically be cleared.



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sequence_number::String

Returns Optional. The sequence number of the message that failed to be ingested.

Returns:

  • (::String)

    Optional. The sequence number of the message that failed to be ingested.



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stream_arn::String

Returns Optional. The stream ARN of the Kinesis stream being ingested from.

Returns:

  • (::String)

    Optional. The stream ARN of the Kinesis stream being ingested from.



707
708
709
710
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 707

class AwsKinesisFailureReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end