Class: Google::Cloud::PubSub::V1::PushConfig
- Inherits:
-
Object
- Object
- Google::Cloud::PubSub::V1::PushConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/pubsub/v1/pubsub.rb
Overview
Configuration for a push delivery endpoint.
Defined Under Namespace
Classes: AttributesEntry, NoWrapper, OidcToken, PubsubWrapper
Instance Attribute Summary collapse
-
#attributes ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#no_wrapper ⇒ ::Google::Cloud::PubSub::V1::PushConfig::NoWrapper
Optional.
-
#oidc_token ⇒ ::Google::Cloud::PubSub::V1::PushConfig::OidcToken
Optional.
-
#pubsub_wrapper ⇒ ::Google::Cloud::PubSub::V1::PushConfig::PubsubWrapper
Optional.
-
#push_endpoint ⇒ ::String
Optional.
Instance Attribute Details
#attributes ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Endpoint configuration attributes that can be used to control different aspects of the message delivery.
The only currently supported attribute is x-goog-version, which you can
use to change the format of the pushed message. This attribute
indicates the version of the data expected by the endpoint. This
controls the shape of the pushed message (i.e., its fields and metadata).
If not present during the CreateSubscription call, it will default to
the version of the Pub/Sub API used to make such call. If not present in a
ModifyPushConfig call, its value will not be changed. GetSubscription
calls will always return a valid version, even if the subscription was
created without this attribute.
The only supported values for the x-goog-version attribute are:
v1beta1: uses the push format defined in the v1beta1 Pub/Sub API.v1orv1beta2: uses the push format defined in the v1 Pub/Sub API.
For example:
attributes { "x-goog-version": "v1" }.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 1478 class PushConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains information needed for generating an # [OpenID Connect # token](https://developers.google.com/identity/protocols/OpenIDConnect). # @!attribute [rw] service_account_email # @return [::String] # Optional. [Service account # email](https://cloud.google.com/iam/docs/service-accounts) # used for generating the OIDC token. For more information # on setting up authentication, see # [Push subscriptions](https://cloud.google.com/pubsub/docs/push). # @!attribute [rw] audience # @return [::String] # Optional. Audience to be used when generating OIDC token. The audience # claim identifies the recipients that the JWT is intended for. The # audience value is a single case-sensitive string. Having multiple values # (array) for the audience field is not supported. More info about the OIDC # JWT token audience here: # https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, # the Push endpoint URL will be used. class OidcToken include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The payload to the push endpoint is in the form of the JSON representation # of a PubsubMessage # (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage). class PubsubWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sets the `data` field as the HTTP body for delivery. # @!attribute [rw] write_metadata # @return [::Boolean] # Optional. When true, writes the Pub/Sub message metadata to # `x-goog-pubsub-<KEY>:<VAL>` headers of the HTTP request. Writes the # Pub/Sub message attributes to `<KEY>:<VAL>` headers of the HTTP request. class NoWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#no_wrapper ⇒ ::Google::Cloud::PubSub::V1::PushConfig::NoWrapper
Returns Optional. When set, the payload to the push endpoint is not wrapped.
Note: The following fields are mutually exclusive: no_wrapper, pubsub_wrapper. If a field in that set is populated, all other fields in the set will automatically be cleared.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 1478 class PushConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains information needed for generating an # [OpenID Connect # token](https://developers.google.com/identity/protocols/OpenIDConnect). # @!attribute [rw] service_account_email # @return [::String] # Optional. [Service account # email](https://cloud.google.com/iam/docs/service-accounts) # used for generating the OIDC token. For more information # on setting up authentication, see # [Push subscriptions](https://cloud.google.com/pubsub/docs/push). # @!attribute [rw] audience # @return [::String] # Optional. Audience to be used when generating OIDC token. The audience # claim identifies the recipients that the JWT is intended for. The # audience value is a single case-sensitive string. Having multiple values # (array) for the audience field is not supported. More info about the OIDC # JWT token audience here: # https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, # the Push endpoint URL will be used. class OidcToken include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The payload to the push endpoint is in the form of the JSON representation # of a PubsubMessage # (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage). class PubsubWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sets the `data` field as the HTTP body for delivery. # @!attribute [rw] write_metadata # @return [::Boolean] # Optional. When true, writes the Pub/Sub message metadata to # `x-goog-pubsub-<KEY>:<VAL>` headers of the HTTP request. Writes the # Pub/Sub message attributes to `<KEY>:<VAL>` headers of the HTTP request. class NoWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#oidc_token ⇒ ::Google::Cloud::PubSub::V1::PushConfig::OidcToken
Returns Optional. If specified, Pub/Sub will generate and attach an OIDC JWT
token as an Authorization header in the HTTP request for every pushed
message.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 1478 class PushConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains information needed for generating an # [OpenID Connect # token](https://developers.google.com/identity/protocols/OpenIDConnect). # @!attribute [rw] service_account_email # @return [::String] # Optional. [Service account # email](https://cloud.google.com/iam/docs/service-accounts) # used for generating the OIDC token. For more information # on setting up authentication, see # [Push subscriptions](https://cloud.google.com/pubsub/docs/push). # @!attribute [rw] audience # @return [::String] # Optional. Audience to be used when generating OIDC token. The audience # claim identifies the recipients that the JWT is intended for. The # audience value is a single case-sensitive string. Having multiple values # (array) for the audience field is not supported. More info about the OIDC # JWT token audience here: # https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, # the Push endpoint URL will be used. class OidcToken include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The payload to the push endpoint is in the form of the JSON representation # of a PubsubMessage # (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage). class PubsubWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sets the `data` field as the HTTP body for delivery. # @!attribute [rw] write_metadata # @return [::Boolean] # Optional. When true, writes the Pub/Sub message metadata to # `x-goog-pubsub-<KEY>:<VAL>` headers of the HTTP request. Writes the # Pub/Sub message attributes to `<KEY>:<VAL>` headers of the HTTP request. class NoWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pubsub_wrapper ⇒ ::Google::Cloud::PubSub::V1::PushConfig::PubsubWrapper
Returns Optional. When set, the payload to the push endpoint is in the form of the JSON representation of a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage).
Note: The following fields are mutually exclusive: pubsub_wrapper, no_wrapper. If a field in that set is populated, all other fields in the set will automatically be cleared.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 1478 class PushConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains information needed for generating an # [OpenID Connect # token](https://developers.google.com/identity/protocols/OpenIDConnect). # @!attribute [rw] service_account_email # @return [::String] # Optional. [Service account # email](https://cloud.google.com/iam/docs/service-accounts) # used for generating the OIDC token. For more information # on setting up authentication, see # [Push subscriptions](https://cloud.google.com/pubsub/docs/push). # @!attribute [rw] audience # @return [::String] # Optional. Audience to be used when generating OIDC token. The audience # claim identifies the recipients that the JWT is intended for. The # audience value is a single case-sensitive string. Having multiple values # (array) for the audience field is not supported. More info about the OIDC # JWT token audience here: # https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, # the Push endpoint URL will be used. class OidcToken include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The payload to the push endpoint is in the form of the JSON representation # of a PubsubMessage # (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage). class PubsubWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sets the `data` field as the HTTP body for delivery. # @!attribute [rw] write_metadata # @return [::Boolean] # Optional. When true, writes the Pub/Sub message metadata to # `x-goog-pubsub-<KEY>:<VAL>` headers of the HTTP request. Writes the # Pub/Sub message attributes to `<KEY>:<VAL>` headers of the HTTP request. class NoWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#push_endpoint ⇒ ::String
Returns Optional. A URL locating the endpoint to which messages should be pushed.
For example, a Webhook endpoint might use https://example.com/push.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 1478 class PushConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains information needed for generating an # [OpenID Connect # token](https://developers.google.com/identity/protocols/OpenIDConnect). # @!attribute [rw] service_account_email # @return [::String] # Optional. [Service account # email](https://cloud.google.com/iam/docs/service-accounts) # used for generating the OIDC token. For more information # on setting up authentication, see # [Push subscriptions](https://cloud.google.com/pubsub/docs/push). # @!attribute [rw] audience # @return [::String] # Optional. Audience to be used when generating OIDC token. The audience # claim identifies the recipients that the JWT is intended for. The # audience value is a single case-sensitive string. Having multiple values # (array) for the audience field is not supported. More info about the OIDC # JWT token audience here: # https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not specified, # the Push endpoint URL will be used. class OidcToken include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The payload to the push endpoint is in the form of the JSON representation # of a PubsubMessage # (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage). class PubsubWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sets the `data` field as the HTTP body for delivery. # @!attribute [rw] write_metadata # @return [::Boolean] # Optional. When true, writes the Pub/Sub message metadata to # `x-goog-pubsub-<KEY>:<VAL>` headers of the HTTP request. Writes the # Pub/Sub message attributes to `<KEY>:<VAL>` headers of the HTTP request. class NoWrapper include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |