Class: Google::Cloud::PubSub::V1::Topic

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/pubsub/v1/pubsub.rb

Overview

A topic resource.

Defined Under Namespace

Modules: State Classes: LabelsEntry, TagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#ingestion_data_source_settings::Google::Cloud::PubSub::V1::IngestionDataSourceSettings

Returns Optional. Settings for ingestion from a data source into this topic.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#kms_key_name::String

Returns Optional. The resource name of the Cloud KMS CryptoKey to be used to protect access to messages published on this topic.

The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*.

Returns:

  • (::String)

    Optional. The resource name of the Cloud KMS CryptoKey to be used to protect access to messages published on this topic.

    The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. See Creating and managing labels.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#message_retention_duration::Google::Protobuf::Duration

Returns Optional. Indicates the minimum duration to retain a message after it is published to the topic. If this field is set, messages published to the topic in the last message_retention_duration are always available to subscribers. For instance, it allows any attached subscription to seek to a timestamp that is up to message_retention_duration in the past. If this field is not set, message retention is controlled by settings on individual subscriptions. Cannot be more than 31 days or less than 10 minutes.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. Indicates the minimum duration to retain a message after it is published to the topic. If this field is set, messages published to the topic in the last message_retention_duration are always available to subscribers. For instance, it allows any attached subscription to seek to a timestamp that is up to message_retention_duration in the past. If this field is not set, message retention is controlled by settings on individual subscriptions. Cannot be more than 31 days or less than 10 minutes.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#message_storage_policy::Google::Cloud::PubSub::V1::MessageStoragePolicy

Returns Optional. Policy constraining the set of Google Cloud Platform regions where messages published to the topic may be stored. If not present, then no constraints are in effect.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#message_transforms::Array<::Google::Cloud::PubSub::V1::MessageTransform>

Returns Optional. Transforms to be applied to messages published to the topic. Transforms are applied in the order specified.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#name::String

Returns Required. Identifier. The name of the topic. It must have the format "projects/{project}/topics/{topic}". {topic} must start with a letter, and contain only letters ([A-Za-z]), numbers ([0-9]), dashes (-), underscores (_), periods (.), tildes (~), plus (+) or percent signs (%). It must be between 3 and 255 characters in length, and it must not start with "goog".

Returns:

  • (::String)

    Required. Identifier. The name of the topic. It must have the format "projects/{project}/topics/{topic}". {topic} must start with a letter, and contain only letters ([A-Za-z]), numbers ([0-9]), dashes (-), underscores (_), periods (.), tildes (~), plus (+) or percent signs (%). It must be between 3 and 255 characters in length, and it must not start with "goog".



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#satisfies_pzs::Boolean

Returns Optional. Reserved for future use. This field is set only in responses from the server; it is ignored if it is set in any requests.

Returns:

  • (::Boolean)

    Optional. Reserved for future use. This field is set only in responses from the server; it is ignored if it is set in any requests.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#schema_settings::Google::Cloud::PubSub::V1::SchemaSettings

Returns Optional. Settings for validating messages published against a schema.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#state::Google::Cloud::PubSub::V1::Topic::State (readonly)

Returns Output only. An output-only field indicating the state of the topic.

Returns:



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end

#tags::Google::Protobuf::Map{::String => ::String}

Returns Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": "marketing" See https://docs.cloud.google.com/pubsub/docs/tags for more information on using tags with Pub/Sub resources.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": "marketing" See https://docs.cloud.google.com/pubsub/docs/tags for more information on using tags with Pub/Sub resources.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 878

class Topic
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the topic.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The topic does not have any persistent errors.
    ACTIVE = 1

    # Ingestion from the data source has encountered a permanent error.
    # See the more detailed error state in the corresponding ingestion
    # source configuration.
    INGESTION_RESOURCE_ERROR = 2
  end
end