Module: Google::Cloud::PubSub::V1::BigtableConfig::State
- Defined in:
- proto_docs/google/pubsub/v1/pubsub.rb
Overview
Possible states for a Bigtable subscription. Note: more states could be added in the future. Please code accordingly.
Constant Summary collapse
- STATE_UNSPECIFIED =
Default value. This value is unused.
0- ACTIVE =
The subscription can actively send messages to Bigtable.
1- NOT_FOUND =
Cannot write to Bigtable because the instance, table, or app profile does not exist.
2- APP_PROFILE_MISCONFIGURED =
Cannot write to Bigtable because the app profile is not configured for single-cluster routing.
3- PERMISSION_DENIED =
Cannot write to Bigtable because of permission denied errors. This can happen if:
- The Pub/Sub service agent has not been granted the appropriate Bigtable IAM permission bigtable.tables.mutateRows
- The bigtable.googleapis.com API is not enabled for the project (instructions)
4- SCHEMA_MISMATCH =
Cannot write to Bigtable because of a missing column family ("data") or if there is no structured row key for the subscription name + message ID.
5- IN_TRANSIT_LOCATION_RESTRICTION =
Cannot write to the destination because enforce_in_transit is set to true and the destination locations are not in the allowed regions.
6- VERTEX_AI_LOCATION_RESTRICTION =
Cannot write to Bigtable because the table is not in the same location as where Vertex AI models used in
message_transforms are deployed. 7