Class: Google::Cloud::PubSub::V1::MessageTransform
- Inherits:
-
Object
- Object
- Google::Cloud::PubSub::V1::MessageTransform
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/pubsub/v1/pubsub.rb
Overview
All supported message transforms types.
Instance Attribute Summary collapse
-
#ai_inference ⇒ ::Google::Cloud::PubSub::V1::AIInference
Optional.
-
#disabled ⇒ ::Boolean
Optional.
-
#enabled ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#javascript_udf ⇒ ::Google::Cloud::PubSub::V1::JavaScriptUDF
Optional.
Instance Attribute Details
#ai_inference ⇒ ::Google::Cloud::PubSub::V1::AIInference
Returns Optional. AI Inference. Specifies the Vertex AI endpoint that inference requests built from the Pub/Sub message data and provided parameters will be sent to.
Note: The following fields are mutually exclusive: ai_inference, javascript_udf. If a field in that set is populated, all other fields in the set will automatically be cleared.
813 814 815 816 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 813 class MessageTransform include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disabled ⇒ ::Boolean
Returns Optional. If true, the transform is disabled and will not be applied to
messages. Defaults to false.
813 814 815 816 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 813 class MessageTransform include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enabled ⇒ ::Boolean
This field is deprecated and may be removed in the next major version update.
Returns Optional. This field is deprecated, use the disabled field to disable
transforms.
813 814 815 816 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 813 class MessageTransform include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#javascript_udf ⇒ ::Google::Cloud::PubSub::V1::JavaScriptUDF
Returns Optional. JavaScript User Defined Function. If multiple JavaScriptUDF's
are specified on a resource, each must have a unique function_name.
Note: The following fields are mutually exclusive: javascript_udf, ai_inference. If a field in that set is populated, all other fields in the set will automatically be cleared.
813 814 815 816 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 813 class MessageTransform include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |