Class: Google::Cloud::PubSub::V1::StreamingPullResponse
- Inherits:
-
Object
- Object
- Google::Cloud::PubSub::V1::StreamingPullResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/pubsub/v1/pubsub.rb
Overview
Response for the StreamingPull method. This response is used to stream
messages from the server to the client.
Defined Under Namespace
Classes: AcknowledgeConfirmation, ModifyAckDeadlineConfirmation, SubscriptionProperties
Instance Attribute Summary collapse
-
#acknowledge_confirmation ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::AcknowledgeConfirmation
Optional.
-
#modify_ack_deadline_confirmation ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::ModifyAckDeadlineConfirmation
Optional.
-
#received_messages ⇒ ::Array<::Google::Cloud::PubSub::V1::ReceivedMessage>
Optional.
-
#subscription_properties ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::SubscriptionProperties
Optional.
Instance Attribute Details
#acknowledge_confirmation ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::AcknowledgeConfirmation
Returns Optional. This field will only be set if enable_exactly_once_delivery is
set to true and is not guaranteed to be populated.
2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 2102 class StreamingPullResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Acknowledgment IDs sent in one or more previous requests to acknowledge a # previously received message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] unordered_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were out of order. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class AcknowledgeConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Acknowledgment IDs sent in one or more previous requests to modify the # deadline for a specific message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class ModifyAckDeadlineConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Subscription properties sent as part of the response. # @!attribute [rw] exactly_once_delivery_enabled # @return [::Boolean] # Optional. True iff exactly once delivery is enabled for this # subscription. # @!attribute [rw] message_ordering_enabled # @return [::Boolean] # Optional. True iff message ordering is enabled for this subscription. class SubscriptionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#modify_ack_deadline_confirmation ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::ModifyAckDeadlineConfirmation
Returns Optional. This field will only be set if enable_exactly_once_delivery is
set to true and is not guaranteed to be populated.
2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 2102 class StreamingPullResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Acknowledgment IDs sent in one or more previous requests to acknowledge a # previously received message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] unordered_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were out of order. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class AcknowledgeConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Acknowledgment IDs sent in one or more previous requests to modify the # deadline for a specific message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class ModifyAckDeadlineConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Subscription properties sent as part of the response. # @!attribute [rw] exactly_once_delivery_enabled # @return [::Boolean] # Optional. True iff exactly once delivery is enabled for this # subscription. # @!attribute [rw] message_ordering_enabled # @return [::Boolean] # Optional. True iff message ordering is enabled for this subscription. class SubscriptionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#received_messages ⇒ ::Array<::Google::Cloud::PubSub::V1::ReceivedMessage>
Returns Optional. Received Pub/Sub messages.
2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 2102 class StreamingPullResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Acknowledgment IDs sent in one or more previous requests to acknowledge a # previously received message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] unordered_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were out of order. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class AcknowledgeConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Acknowledgment IDs sent in one or more previous requests to modify the # deadline for a specific message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class ModifyAckDeadlineConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Subscription properties sent as part of the response. # @!attribute [rw] exactly_once_delivery_enabled # @return [::Boolean] # Optional. True iff exactly once delivery is enabled for this # subscription. # @!attribute [rw] message_ordering_enabled # @return [::Boolean] # Optional. True iff message ordering is enabled for this subscription. class SubscriptionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subscription_properties ⇒ ::Google::Cloud::PubSub::V1::StreamingPullResponse::SubscriptionProperties
Returns Optional. Properties associated with this subscription.
2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'proto_docs/google/pubsub/v1/pubsub.rb', line 2102 class StreamingPullResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Acknowledgment IDs sent in one or more previous requests to acknowledge a # previously received message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] unordered_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were out of order. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class AcknowledgeConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Acknowledgment IDs sent in one or more previous requests to modify the # deadline for a specific message. # @!attribute [rw] ack_ids # @return [::Array<::String>] # Optional. Successfully processed acknowledgment IDs. # @!attribute [rw] invalid_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that were malformed or whose # acknowledgment deadline has expired. # @!attribute [rw] temporary_failed_ack_ids # @return [::Array<::String>] # Optional. List of acknowledgment IDs that failed processing with # temporary issues. class ModifyAckDeadlineConfirmation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Subscription properties sent as part of the response. # @!attribute [rw] exactly_once_delivery_enabled # @return [::Boolean] # Optional. True iff exactly once delivery is enabled for this # subscription. # @!attribute [rw] message_ordering_enabled # @return [::Boolean] # Optional. True iff message ordering is enabled for this subscription. class SubscriptionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |